pub struct Model {
pub id: String,
pub created: i64,
pub object: String,
pub owned_by: String,
}Expand description
Describes an OpenAI model offering that can be used with the API.
Fields
id: StringThe model identifier, which can be referenced in the API endpoints.
created: i64The Unix timestamp (in seconds) when the model was created.
object: StringThe object type, which is always “model”.
owned_by: StringThe organization that owns the model.